from com import Component, msgs
from ui.Button import Button
from ui.Label import Label
from ui.layout import Arrangement
from ui.Window import Window
from theme import theme

import gtk


_PORTRAIT_ARRANGEMENT = """
  <arrangement>
    <widget name="lbl_code" x1="1%" y1="0%" x2="99%" y2="15%"/>
    
    <widget name="btn_1" x1="1%" y1="15%" x2="33%" y2="31%"/>
    <widget name="btn_2" x1="34%" y1="15%" x2="66%" y2="31%"/>
    <widget name="btn_3" x1="67%" y1="15%" x2="99%" y2="31%"/>

    <widget name="btn_4" x1="1%" y1="32%" x2="33%" y2="48%"/>
    <widget name="btn_5" x1="34%" y1="32%" x2="66%" y2="48%"/>
    <widget name="btn_6" x1="67%" y1="32%" x2="99%" y2="48%"/>

    <widget name="btn_7" x1="1%" y1="49%" x2="33%" y2="65%"/>
    <widget name="btn_8" x1="34%" y1="49%" x2="66%" y2="65%"/>
    <widget name="btn_9" x1="67%" y1="49%" x2="99%" y2="65%"/>

    <widget name="btn_star" x1="1%" y1="66%" x2="33%" y2="82%"/>
    <widget name="btn_0" x1="34%" y1="66%" x2="66%" y2="82%"/>
    <widget name="btn_hash" x1="67%" y1="66%" x2="99%" y2="82%"/>

    <widget name="btn_send" x1="1%" y1="83%" x2="66%" y2="99%"/>
    <widget name="btn_back" x1="67%" y1="83%" x2="99%" y2="99%"/>
  </arrangement>
"""


class MainWindow(Component, Window):

    def __init__(self):
    
        self.__current_code = ""
        
    
        Component.__init__(self)
        Window.__init__(self, Window.TYPE_TOPLEVEL)
        self.set_title("USSD Pad")
        self.set_portrait_mode(True)
        self.connect_closed(self.__on_close_window)
        
        self.__arr = Arrangement()
        self.add(self.__arr)
        
        self.__lbl_code = Label("", theme.font_ui_plain, theme.color_ui_text)
        self.__arr.add(self.__lbl_code, "lbl_code")
        
        for lbl, name in [("1", "btn_1"),
                          ("2", "btn_2"),
                          ("3", "btn_3"),
                          ("4", "btn_4"),
                          ("5", "btn_5"),
                          ("6", "btn_6"),
                          ("7", "btn_7"),
                          ("8", "btn_8"),
                          ("9", "btn_9"),
                          ("0", "btn_0"),
                          ("*", "btn_star"),
                          ("#", "btn_hash"),
                          ("SEND", "btn_send"),
                          ("BACK", "btn_back")]:
            btn = Button(lbl)
            btn.connect_clicked(self.__on_button, lbl)
            self.__arr.add(btn, name)
        #end for
    
        self.__arr.set_xml(_PORTRAIT_ARRANGEMENT)
    
        self.set_visible(True)


    def set_size(self, w, h):
    
        old_w, old_h = self.get_size()
        if ((w, h) != (old_w, old_h)):
            Window.set_size(self, w, h)
            self.__arr.set_geometry(0, 0, w, h)


    def render_this(self):
    
        w, h = self.get_size()
        screen = self.get_screen()
        
        screen.fill_area(0, 0, w, h, theme.color_ui_background)
        
        #self.__arr.set_geometry(0, 0, w, h)


    def __on_close_window(self):
    
        gtk.main_quit()


    def __on_button(self, lbl):
    
        if (lbl == "SEND"):
            msg = self.call_service(msgs.USSD_SVC_SEND, self.__current_code)
            self.__set_code("")
            print "MESSAGE", msg
            self.__lbl_code.set_text(msg or " ")

        elif (lbl == "BACK"):
            self.__set_code(self.__current_code[:-1])

        else:
            self.__set_code(self.__current_code + lbl)

        
    def __set_code(self, new_code):
    
        self.__current_code = new_code
        self.__lbl_code.set_text(new_code or " ")

